%global        _legacy_common_support 1

%define        hbin	    bin

Summary:       Image Reduction and Analysis Facility
Name:          iraf
Version:       2.18
Release:       %mkrel 1
License:       MIT-like
Group:         Sciences/Astronomy
Url:           https://iraf-community.github.io/
Source0:       https://github.com/iraf-community/iraf/archive/v%{version}/%{name}-%{version}.tar.gz
# From Debian
Source11:      iraf.desktop
Source12:      iraf.svg
Source13:      precompile.cl

#adusted to mga
Patch0:      iraf-2.18-vnum-motd.patch
Patch1:      iraf-2.18-skip-source-dependent-tests.patch
Patch2:      iraf-2.18-ensure-reproducible-build.patch

#arch dep lib dir name
Patch10:      iraf-2.18-libfix.patch

BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(expat)
BuildRequires: readline-devel
BuildRequires: pkgconfig(cfitsio)
BuildRequires: xmlrpc-c-devel
BuildRequires: f2c
BuildRequires: tcsh
BuildRequires: flex

BuildRequires: bison
BuildRequires: pkgconfig(ncurses)
Requires:      f2c
Requires:      bison

%description
IRAF stands for the Image Reduction and Analysis Facility. It
is the de facto standard for the general processing of astronomical images
and spectroscopy from the ultraviolet to the far infrared. IRAF is a
product of the National Optical Astronomy Observatories (www.noao.edu).

%package noao
Summary:       IRAF NOAO data reduction package
Group:         Sciences/Astronomy
Requires:      iraf = %{version}-%{release}

%description noao
IRAF stands for the Image Reduction and Analysis Facility. It
is the de facto standard for the general processing of astronomical images
and spectroscopy from the ultraviolet to the far infrared. IRAF is a
product of the National Optical Astronomy Observatories (www.noao.edu).

This file contains the NOAO packages for the reduction and analysis
of Optical Astronomy data.

%package devel
Summary:       Image Reduction and Analysis Facility (development files)
Group:         Sciences/Astronomy
Requires:      iraf = %{version}-%{release}

%description devel
IRAF stands for the Image Reduction and Analysis Facility. It
is the de facto standard for the general processing of astronomical images
and spectroscopy from the ultraviolet to the far infrared. IRAF is a
product of the National Optical Astronomy Observatories (www.noao.edu).

This package contains the IMFORT Fortran/C programming interface, and
the full SPP/VOS programming environment in which the portable IRAF
system and all applications are written.

%package noao-devel
Summary:       IRAF NOAO data reduction package (development files)
Group:         Sciences/Astronomy
Requires:      iraf-devel = %{version}-%{release}
Requires:      iraf-noao = %{version}-%{release}

%description noao-devel
IRAF stands for the Image Reduction and Analysis Facility. It
is the de facto standard for the general processing of astronomical images
and spectroscopy from the ultraviolet to the far infrared. IRAF is a
product of the National Optical Astronomy Observatories (www.noao.edu).

This package contains additional libraries and headers used for
compiling packages that extend the functionality of the iraf-noao
package.

%prep
%setup -q -n %{name}-%{version}
%autopatch -p1

%build

export CC='gcc'
export CFLAGS="%{optflags} -Wno-incompatible-pointer-types"
export IRAFARCH=''
export iraf=$(pwd)/
bin=${iraf}bin/ noaobin=${iraf}/noao/bin/ %make_build 
./bin/cl.e -f %{SOURCE13}

%install


prefix=%{_prefix} libfix=%{_lib} %make_install IRAFARCH=''

mkdir -p %{buildroot}%{_datadir}/applications
install -Dpm644 %{_sourcedir}/iraf.desktop %{buildroot}%{_datadir}/applications/iraf.desktop

mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -Dpm644 %{_sourcedir}/iraf.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/iraf.svg

%__mkdir_p %{buildroot}%{_includedir}
%__ln_s %{_libdir}/iraf/unix/hlib/libc/iraf.h %{buildroot}%{_includedir}/iraf.h


%files
%doc doc/*
%dir %{_libdir}/iraf/
%dir %{_libdir}/iraf/lib/
%dir %{_libdir}/iraf/lib/scr/
%{_libdir}/iraf/lib/scr/*
%{_libdir}/iraf/lib/helpdb.mip
%{_libdir}/iraf/lib/syserrmsg
%{_libdir}/iraf/lib/syshelpdir
%{_libdir}/iraf/lib/clpackage.hd
%{_libdir}/iraf/lib/root.hd
%dir %{_libdir}/iraf/dev/
%{_libdir}/iraf/dev/*
%dir %{_libdir}/iraf/pkg/
%dir %{_libdir}/iraf/pkg/bench/
%{_libdir}/iraf/pkg/bench/*
%dir %{_libdir}/iraf/pkg/lists/
%{_libdir}/iraf/pkg/lists/*
%dir %{_libdir}/iraf/pkg/cl/
%{_libdir}/iraf/pkg/cl/*
%dir %{_libdir}/iraf/pkg/language/
%{_libdir}/iraf/pkg/language/*
%dir %{_libdir}/iraf/pkg/system/
%{_libdir}/iraf/pkg/system/*
%dir %{_libdir}/iraf/pkg/obsolete/
%{_libdir}/iraf/pkg/obsolete/*
%dir %{_libdir}/iraf/pkg/plot/
%{_libdir}/iraf/pkg/plot/*
%dir %{_libdir}/iraf/pkg/xtools/
%{_libdir}/iraf/pkg/xtools/*
%dir %{_libdir}/iraf/pkg/proto/
%{_libdir}/iraf/pkg/proto/*
%dir %{_libdir}/iraf/pkg/ecl/
%{_libdir}/iraf/pkg/ecl/*
%dir %{_libdir}/iraf/pkg/utilities/
%{_libdir}/iraf/pkg/utilities/*
%dir %{_libdir}/iraf/pkg/dataio/
%{_libdir}/iraf/pkg/dataio/*
%dir %{_libdir}/iraf/pkg/images/
%{_libdir}/iraf/pkg/images/*
%dir %{_libdir}/iraf/pkg/softools/
%{_libdir}/iraf/pkg/softools/*
%dir %{_libdir}/iraf/sys/
%{_libdir}/iraf/sys/*
%dir %{_libdir}/iraf/math/
%{_libdir}/iraf/math/*
%dir %{_libdir}/iraf/bin
%{_libdir}/iraf/%{hbin}/cl.e
%{_libdir}/iraf/%{hbin}/ecl.e
%{_libdir}/iraf/%{hbin}/irafks.e
%{_libdir}/iraf/%{hbin}/x_*.e
%dir %{_libdir}/iraf/unix/%{hbin}
%{_libdir}/iraf/unix/%{hbin}/*.e
%dir %{_libdir}/iraf/unix/boot/
%{_libdir}/iraf/unix/boot/*
%dir %{_libdir}/iraf/unix/os/
%{_libdir}/iraf/unix/os/*
%dir %{_libdir}/iraf/local/
%{_libdir}/iraf/local/*
%{_libdir}/iraf/extern/*
%dir %{_libdir}/iraf/unix/hlib/
%{_libdir}/iraf/unix/hlib/motd
%{_libdir}/iraf/unix/hlib/*.cl
%{_libdir}/iraf/unix/hlib/*.sh
%exclude %{_libdir}/iraf/unix/hlib/f77.sh
%{_libdir}/iraf/unix/hlib/clpackage.hd
%{_libdir}/iraf/unix/hlib/clpackage.men
%{_libdir}/iraf/unix/hlib/extern.pkg
%{_libdir}/iraf/unix/hlib/mkfloat
%{_libdir}/iraf/unix/hlib/motd.etc
%dir %{_libdir}/iraf/test
%{_libdir}/iraf/test/*.md
%{_libdir}/iraf/test/run_tests
%{_libdir}/iraf/unix/hlib/zzsetenv.def
%{_bindir}/irafcl
%{_bindir}/sgidispatch
%{_bindir}/cl
%{_bindir}/ecl
%{_bindir}/mkiraf
%{_bindir}/rmbin
%{_bindir}/rmfiles
%{_bindir}/rtar
%{_bindir}/wtar
%dir %{_sysconfdir}/iraf/
%{_sysconfdir}/iraf/irafroot
%{_mandir}/man1/*.1.*
%{_datadir}/applications/iraf.desktop
%{_iconsdir}/hicolor/scalable/apps/iraf.svg

%files noao
%dir %{_libdir}/iraf/noao/
%dir %{_libdir}/iraf/noao/artdata/
%{_libdir}/iraf/noao/artdata/*
%dir %{_libdir}/iraf/noao/astcat/
%{_libdir}/iraf/noao/astcat/*
%dir %{_libdir}/iraf/noao/astrometry/
%{_libdir}/iraf/noao/astrometry/*
%dir %{_libdir}/iraf/noao/astutil/
%{_libdir}/iraf/noao/astutil/*
#{_libdir}/iraf/noao/bin/
%dir %{_libdir}/iraf/noao/%{hbin}
%{_libdir}/iraf/noao/%{hbin}/x_*.e
%dir %{_libdir}/iraf/noao/digiphot
%{_libdir}/iraf/noao/digiphot/*
%dir %{_libdir}/iraf/noao/filterphot/
%{_libdir}/iraf/noao/filterphot/*
%dir %{_libdir}/iraf/noao/focas/
%{_libdir}/iraf/noao/focas/*
%dir %{_libdir}/iraf/noao/imred/
%{_libdir}/iraf/noao/imred/*
%dir %{_libdir}/iraf/noao/lib/
%{_libdir}/iraf/noao/lib/*
%exclude %{_libdir}/iraf/noao/lib/*.h
%exclude %{_libdir}/iraf/noao/lib/*.inc
%dir %{_libdir}/iraf/noao/mtlocal/
%{_libdir}/iraf/noao/mtlocal/*
%{_libdir}/iraf/noao/noao.cl
%{_libdir}/iraf/noao/noao.hd
%{_libdir}/iraf/noao/noao.men
%{_libdir}/iraf/noao/noao.par
%dir %{_libdir}/iraf/noao/nobsolete/
%{_libdir}/iraf/noao/nobsolete/*
%dir %{_libdir}/iraf/noao/nproto/
%{_libdir}/iraf/noao/nproto/*
%dir %{_libdir}/iraf/noao/obsutil/
%{_libdir}/iraf/noao/obsutil/*
%dir %{_libdir}/iraf/noao/onedspec/
%{_libdir}/iraf/noao/onedspec/*
%dir %{_libdir}/iraf/noao/rv/
%{_libdir}/iraf/noao/rv/*
%dir %{_libdir}/iraf/noao/surfphot/
%{_libdir}/iraf/noao/surfphot/*
%dir %{_libdir}/iraf/noao/twodspec/
%{_libdir}/iraf/noao/twodspec/*
%exclude %{_libdir}/iraf/noao/*/*.a

# dev files
%files devel
%{_includedir}/iraf.h
%{_bindir}/mkpkg
%{_bindir}/xc
%{_bindir}/xyacc
%{_libdir}/iraf/%{hbin}/lib*.a
%{_libdir}/iraf/%{hbin}/libmain.o
%dir %{_libdir}/iraf/include/
%{_libdir}/iraf/include/*.h
%dir %{_libdir}/iraf/lib
%{_libdir}/iraf/lib/*.h
%{_libdir}/iraf/lib/*.inc
%{_libdir}/iraf/lib/*.a
%{_libdir}/iraf/lib/*.com
%{_libdir}/iraf/lib/names
%{_libdir}/iraf/lib/*.x
%{_libdir}/iraf/lib/math/*.h
%{_libdir}/iraf/lib/pkg/*.h
%{_libdir}/iraf/unix/%{hbin}/f2c.e
%{_libdir}/iraf/unix/%{hbin}/generic.e
%{_libdir}/iraf/unix/%{hbin}/libboot.a
%{_libdir}/iraf/unix/%{hbin}/libf2c.a
%{_libdir}/iraf/unix/%{hbin}/libos.a
%{_libdir}/iraf/unix/%{hbin}/mkpkg.e
%{_libdir}/iraf/unix/%{hbin}/rm%{hbin}.e
%{_libdir}/iraf/unix/%{hbin}/rmfiles.e
%{_libdir}/iraf/unix/%{hbin}/rpp.e
%{_libdir}/iraf/unix/%{hbin}/rtar.e
%{_libdir}/iraf/unix/%{hbin}/wtar.e
%{_libdir}/iraf/unix/%{hbin}/xc.e
%{_libdir}/iraf/unix/%{hbin}/xpp.e
%{_libdir}/iraf/unix/%{hbin}/xyacc.e
%{_libdir}/iraf/unix/hlib/strip.iraf
%{_libdir}/iraf/unix/hlib/*.a
%{_libdir}/iraf/unix/hlib/*.man
%{_libdir}/iraf/unix/hlib/*.csh
%{_libdir}/iraf/unix/hlib/*.f
%{_libdir}/iraf/unix/hlib/*.h
%{_libdir}/iraf/unix/hlib/*.inc
%{_libdir}/iraf/unix/hlib/*.sf
%{_libdir}/iraf/unix/hlib/f77.sh
%dir %{_libdir}/iraf/unix/hlib/libc
%{_libdir}/iraf/unix/hlib/libc/*

# noao dev files
%files noao-devel
%{_libdir}/iraf/noao/%{hbin}/lib*.a
%{_libdir}/iraf/noao/lib/*.h
%{_libdir}/iraf/noao/lib/*.inc


%changelog
* Wed May 08 2024 eatdirt <eatdirt> 2.18-1.mga10
+ Revision: 2062945
- Upgrade to version 2.18, monster spec cleaning in progress

* Sun Dec 04 2022 eatdirt <eatdirt> 2.17-3.mga9
+ Revision: 1917817
- Rebuild for new cfitsio

* Sun Dec 04 2022 daviddavid <daviddavid> 2.17-2.mga9
+ Revision: 1917714
- rebuild for new cfitsio 4.2.0

* Fri Aug 26 2022 eatdirt <eatdirt> 2.17-1.mga9
+ Revision: 1880654
- Upgrade to version 2.17

* Sat Apr 02 2022 umeabot <umeabot> 2.16.1-2018.11.01.6.mga9
+ Revision: 1840839
- Mageia 9 Mass Rebuild

* Mon Sep 07 2020 eatdirt <eatdirt> 2.16.1-2018.11.01.5.mga8
+ Revision: 1623181
- Fix double call to make
- Fix path and built setup
- Rebuild for new cfitsio
+ daviddavid <daviddavid>
- rebuild for new cfitsio 3.480

* Sat Jun 27 2020 joequant <joequant> 2.16.1-2018.11.01.2.mga8
+ Revision: 1599495
- add gcc10 patch
- rebuild for bootstrap
- fix bootstrap

* Fri Mar 20 2020 eatdirt <eatdirt> 2.16.1-2018.11.01.1.mga8
+ Revision: 1558375
- Upgrade to snapdate 2018.11.01

* Tue Feb 18 2020 umeabot <umeabot> 2.16.1-2018.06.15.3.mga8
+ Revision: 1542176
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 2.16.1-2018.06.15.2.mga8
+ Revision: 1475971
- rebuild for readline

* Mon Sep 10 2018 wally <wally> 2.16.1-2018.06.15.1.mga7
+ Revision: 1258154
- switch to IRAF community edition
- new snapshot release 2.16.1+2018.06.15
- sync with Debian
- add new subpkgs devel, noao and noao-devel

* Sun May 13 2018 daviddavid <daviddavid> 2.16-26.mga7
+ Revision: 1228765
- rebuild for new cfitsio 3.450

* Sun Apr 08 2018 daviddavid <daviddavid> 2.16-25.mga7
+ Revision: 1216151
- rebuild for new xmlrpc-c 1.51.0

* Tue Jan 02 2018 wally <wally> 2.16-24.mga7
+ Revision: 1189444
- rebuild for new readline

* Wed Nov 30 2016 pterjan <pterjan> 2.16-23.mga6
+ Revision: 1071119
- Fix missing amov* symbols on arm

* Tue Nov 22 2016 eatdirt <eatdirt> 2.16-22.mga6
+ Revision: 1068820
- Rebuild for new cfitsio

* Tue Nov 01 2016 eatdirt <eatdirt> 2.16-21.mga6
+ Revision: 1064628
- Fix segmentation violation by compiling with -O0 and cleaning patches

* Fri Oct 28 2016 pterjan <pterjan> 2.16-20.mga6
+ Revision: 1063808
- Also create bindir under unix/
- Create dir also in our patch, not sure if used
- Create arch bin directory if it does not exist

* Thu Oct 27 2016 pterjan <pterjan> 2.16-19.mga6
+ Revision: 1063784
- Fix problems in the arm patch causing missing binaries on other architectures

* Mon Aug 01 2016 pterjan <pterjan> 2.16-18.mga6
+ Revision: 1044189
- Try to fix arm again...

* Mon Aug 01 2016 pterjan <pterjan> 2.16-17.mga6
+ Revision: 1044182
- Fix patch to not break i586
- Make it work on arm (most important part is from Debian)

* Thu Mar 10 2016 eatdirt <eatdirt> 2.16-15.mga6
+ Revision: 988671
- Rebuild for new cfitsio

* Wed Feb 03 2016 umeabot <umeabot> 2.16-14.mga6
+ Revision: 933050
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.16-13.mga5
+ Revision: 743625
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 2.16-12.mga5
+ Revision: 725095
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 2.16-11.mga5
+ Revision: 680561
- Mageia 5 Mass Rebuild

* Fri Feb 28 2014 eatdirt <eatdirt> 2.16-10.mga5
+ Revision: 597730
- Rebuild for new cfitsio
+ joequant <joequant>
- add O2 optimizations to everything
  O3 will cause garbage output

* Thu Oct 31 2013 joequant <joequant> 2.16-8.mga4
+ Revision: 548711
- fix double memory alignment problem
  second pass at fix for 11507

* Tue Oct 29 2013 joequant <joequant> 2.16-7.mga4
+ Revision: 547906
- fix bug 11507

* Sat Oct 19 2013 umeabot <umeabot> 2.16-6.mga4
+ Revision: 531780
- Mageia 4 Mass Rebuild

* Sat Aug 10 2013 eatdirt <eatdirt> 2.16-5.mga4
+ Revision: 465260
- Packaging missing pkg/cl.par files to fix CL crash

* Sun Jul 28 2013 joequant <joequant> 2.16-4.mga4
+ Revision: 459363
- tweak spec not to clean out object files for devkit
- more spec tweaks

* Sun Jul 28 2013 joequant <joequant> 2.16-3.mga4
+ Revision: 459343
- tweak requires to set up devkit correctly

* Sun Jul 28 2013 joequant <joequant> 2.16-2.mga4
+ Revision: 459331
- don't delete .h from iraf distribution

* Sat Jul 27 2013 joequant <joequant> 2.16-1.mga4
+ Revision: 458839
- add CFITSIO variable
- use custom iraf for 32 bit also
- remove extra curl files and unneeded build requires
- add debian fixes
- add xmlrpc-c-devel to buildrequires
- use external xmlrpc
  remove unnecessary external files
- update build patch
  fix iraf data location
- add java requires
- clean up spec files
- change more default directory paths
- comment out yacc
- use host cfitsio
- using implicit length arrays in RPP to avoid overflows
- checkpoint with latest changes
- imported package iraf

